Attribute VB_Name = "Edit"
'/*
'WordBastard - rich text editor
'Edit.bas - edit routines
'Copyright  (C) 1998-2000 Hugues Johnson
'
'This program is free software; you can redistribute it and/or
'modify it under the terms of the GNU General Public License
'as published by the Free Software Foundation; either version 2
'of the License, or (at your option) any later version.
'
'This program is distributed in the hope that it will be useful,
'but WITHOUT ANY WARRANTY; without even the implied warranty of
'MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
'the GNU General Public License for more details.
'
'You should have received a copy of the GNU General Public License
'along with this program; if not, write to the Free Software
'Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
'*/

Public Function HighlightWords(rtf As Control, FindString As String, lColor As Long, lOptions As Long)
    Dim lFoundPos As Long
    Dim lFindLength As Long
    Dim lOriginalSelStart As Long
    Dim lOriginalSelLength As Long
    Dim iMatchCount As Integer
    
    On Error GoTo errHighlightWords
    
    If (TypeOf rtf Is RichTextBox) Then
        lOriginalSelStart = rtf.SelStart
        lOriginalSelLength = rtf.SelLength
        
        lFindLength = Len(FindString)
        
        lFoundPos = rtf.Find(FindString, 0, , lOptions)
        
        While (lFoundPos > 0)
            iMatchCount = iMatchCount + 1
            rtf.SelStart = lFoundPos
            rtf.SelLength = lFindLength
            rtf.SelColor = lColor
            lFoundPos = rtf.Find(FindString, lFoundPos + lFindLength, , lOptions)
        Wend
    
        rtf.SelStart = lOriginalSelStart
        rtf.SelLength = lOriginalSelLength
        
    End If
    
    HighlightWords = iMatchCount
    
exitFunction:
    Exit Function

errHighlightWords:
    ErrorHandler Err, "HighlightWords"
    Resume exitFunction
    
End Function

Public Sub FindNext(rtf As Control, FindString As String, lOptions As Long)
    Dim lFoundPos As Long
    Dim lFoundLine As Long
    
    On Error GoTo errFindNext:
    
    If (TypeOf rtf Is RichTextBox) Then
        lFoundPos = rtf.Find(FindString, rtf.SelStart + Len(FindString), , lOptions)
    
        If (lFoundPos = -1) Then
            MsgBox "Search string was not found.", vbOKOnly + vbExclamation, "WordBastard"
        Else
            rtf.SelStart = lFoundPos
            rtf.SelLength = Len(FindString)
        End If
    
    End If

exitSub:
    Exit Sub

errFindNext:
    ErrorHandler Err, "FindNext"
    Resume exitSub

End Sub

Public Sub ReplaceText(rtf As Control, FindText As String, ReplaceText As String)

    On Error GoTo errReplaceText

    If (TypeOf rtf Is RichTextBox) Then
        If (UCase$(rtf.SelText) = UCase$(FindText)) Then
            rtf.SelText = ReplaceText
        End If
    End If

exitSub:
    Exit Sub

errReplaceText:
    ErrorHandler Err, "ReplaceText"
    Resume exitSub
    
End Sub

Public Function ReplaceAll(rtf As Control, FindText As String, ReplaceText As String, lOptions As Long)
    Dim lFoundPos As Long
    Dim lFindLength As Long
    Dim lOriginalSelStart As Long
    Dim lOriginalSelLength As Long
    Dim iMatchCount As Integer
    
    On Error GoTo errReplaceAll
    
    If (TypeOf rtf Is RichTextBox) Then
        lOriginalSelStart = rtf.SelStart
        lOriginalSelLength = rtf.SelLength
        
        lFindLength = Len(FindText)
        
        lFoundPos = rtf.Find(FindText, 0, , lOptions)
        
        While (lFoundPos > 0)
            iMatchCount = iMatchCount + 1
            rtf.SelStart = lFoundPos
            rtf.SelLength = lFindLength
            rtf.SelText = ReplaceText
            lFoundPos = rtf.Find(FindText, lFoundPos + lFindLength, , lOptions)
        Wend
    
        rtf.SelStart = lOriginalSelStart
        rtf.SelLength = lOriginalSelLength
        
    End If
    
    ReplaceAll = iMatchCount

exitFunction:
    Exit Function

errReplaceAll:
    ErrorHandler Err, "ReplaceAll"
    Resume exitFunction

End Function

Public Sub CopyText(rtf As Control)

    On Error GoTo errCopyText
    
    If (TypeOf rtf Is RichTextBox) Then
        Clipboard.SetText rtf.SelText, vbCFText
    End If
    
exitSub:
    Exit Sub

errCopyText:
    Call ErrorHandler(Err, "CopyText", "")
    Resume exitSub

End Sub

Public Sub CutText(rtf As Control)

    On Error GoTo errCutText

    If (TypeOf rtf Is RichTextBox) Then
        If (Trim$(rtf.SelText <> "")) Then
            Clipboard.SetText rtf.SelText, vbCFText
            rtf.SelText = ""
        End If
    End If

exitSub:
    Exit Sub

errCutText:
    ErrorHandler Err, "CutText"
    Resume exitSub
    
End Sub

Public Sub PasteText(rtf As Control)

    On Error GoTo errPasteText
    
    If (TypeOf rtf Is RichTextBox) Then
        rtf.SelText = Clipboard.GetText(vbCFText)
    End If
    
exitSub:
    Exit Sub

errPasteText:
    ErrorHandler Err, "PasteText"
    Resume exitSub

End Sub

Public Sub SelectAll(rtf As Control)
    
    If (TypeOf rtf Is RichTextBox) Then
        rtf.SelStart = 0
        rtf.SelLength = Len(rtf.Text)
    End If

End Sub

Public Sub ClearText(rtf As Control)
    
    On Error GoTo errClearText

    If (TypeOf rtf Is RichTextBox) Then
        If (Trim$(rtf.SelText <> "")) Then
            rtf.SelText = ""
        End If
    End If

exitSub:
    Exit Sub

errClearText:
    ErrorHandler Err, "ClearText"
    Resume exitSub

End Sub
